# eric7.Plugins.VcsPlugins.vcsGit.GitBranchDialog

Module implementing a dialog to enter the data for a branching operation.

### Global Attributes

None

### Classes

GitBranchDialog | Class implementing a dialog to enter the data for a branching operation.

### Functions

None

## GitBranchDialog

Class implementing a dialog to enter the data for a branching operation.

### Derived from

QDialog, Ui_GitBranchDialog

### Class Attributes

CreateBranch
CreateSwitchBranch
CreateTrackingBranch
DeleteBranch
RenameBranch
SetTrackingBranch
UnsetTrackingBranch

### Class Methods

None

### Methods

GitBranchDialog | Constructor
__updateOK | Private method used to enable/disable the OK-button.
getParameters | Public method to retrieve the branch data.
on_branchCombo_editTextChanged | Private slot to handle a change of the branch.
on_createTrackingButton_toggled | Private slot to handle the selection of creating a tracking branch.
on_newBranchNameEdit_textChanged | Private slot to handle a change of the new branch.
on_setTrackingButton_toggled | Private slot to handle the selection of setting a tracking branch.
on_unsetTrackingButton_toggled | Private slot to handle the selection of unsetting a tracking branch.

### Static Methods

None

#### GitBranchDialog (Constructor)

GitBranchDialog(branchlist, revision=None, branchName=None, branchOp=None, parent=None)

Constructor

branchlist (list of str)
  list of previously entered branches
revision (str)
  revision to set tag for
branchName (str)
  name of the branch
branchOp (int)
  desired branch operation
parent (QWidget)
  parent widget

#### GitBranchDialog.__updateOK

__updateOK()

Private method used to enable/disable the OK-button.

#### GitBranchDialog.getParameters

getParameters()

Public method to retrieve the branch data.

Return:
  tuple containing the branch operation, branch name, revision, new branch name, remote branch name and a flag indicating to enforce the operation

Return Type:
  tuple of (int, str, str, str, str, bool)

#### GitBranchDialog.on_branchCombo_editTextChanged

on_branchCombo_editTextChanged(text)

Private slot to handle a change of the branch.

text (str)
  branch name entered in the combo

#### GitBranchDialog.on_createTrackingButton_toggled

on_createTrackingButton_toggled(checked)

Private slot to handle the selection of creating a tracking branch.

checked (bool)
  state of the selection

#### GitBranchDialog.on_newBranchNameEdit_textChanged

on_newBranchNameEdit_textChanged(text)

Private slot to handle a change of the new branch.

text (str)
  new branch name entered

#### GitBranchDialog.on_setTrackingButton_toggled

on_setTrackingButton_toggled(checked)

Private slot to handle the selection of setting a tracking branch.

checked (bool)
  state of the selection

#### GitBranchDialog.on_unsetTrackingButton_toggled

on_unsetTrackingButton_toggled(checked)

Private slot to handle the selection of unsetting a tracking branch.

checked (bool)
  state of the selection

Up